<?php

namespace Litecms\BusCategory\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\BusCategory\Http\Requests\BusCategoryRequest;
use Litecms\BusCategory\Models\BusCategory;

/**
 * Admin web controller class.
 */
class BusCategoryWorkflowController extends BaseController
{

    /**
     * Workflow controller function for bus_category.
     *
     * @param Model   $bus_category
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(BusCategoryRequest $request, BusCategory $bus_category, $step)
    {

        try {

            $bus_category->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('bus_category::bus_category.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/bus_category/bus_category/' . $bus_category->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/bus_category/bus_category/' . $bus_category->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for bus_category.
     *
     * @param Model   $bus_category
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(BusCategory $bus_category, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $bus_category->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('bus_category::bus_category.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('bus_category::admin.bus_category.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('bus_category::admin.bus_category.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('bus_category::admin.bus_category.message', $data)->render();

        }

    }
}
