<?php

namespace Litecms\BusCategory\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\BusCategory\Models\BusCategory;

class BusCategoryAction
{
    /**
     * Perform the complete action.
     *
     * @param BusCategory $bus_category
     *
     * @return BusCategory
     */
    public function complete(BusCategory $bus_category)
    {
        try {
            $bus_category->status = 'complete';
            return $bus_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param BusCategory $bus_category
     *
     * @return BusCategory
     */public function verify(BusCategory $bus_category)
    {
        try {
            $bus_category->status = 'verify';
            return $bus_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param BusCategory $bus_category
     *
     * @return BusCategory
     */public function approve(BusCategory $bus_category)
    {
        try {
            $bus_category->status = 'approve';
            return $bus_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param BusCategory $bus_category
     *
     * @return BusCategory
     */public function publish(BusCategory $bus_category)
    {
        try {
            $bus_category->status = 'publish';
            return $bus_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param BusCategory $bus_category
     *
     * @return BusCategory
     */
    public function archive(BusCategory $bus_category)
    {
        try {
            $bus_category->status = 'archive';
            return $bus_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param BusCategory $bus_category
     *
     * @return BusCategory
     */
    public function unpublish(BusCategory $bus_category)
    {
        try {
            $bus_category->status = 'unpublish';
            return $bus_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
