<?php

namespace Litecms\BusCategory\Workflow;

use Litecms\BusCategory\Models\BusCategory;
use Validator;

class BusCategoryValidator
{

    /**
     * Determine if the given bus_category is valid for complete status.
     *
     * @param BusCategory $bus_category
     *
     * @return bool / Validator
     */
    public function complete(BusCategory $bus_category)
    {
        return Validator::make($bus_category->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given bus_category is valid for verify status.
     *
     * @param BusCategory $bus_category
     *
     * @return bool / Validator
     */
    public function verify(BusCategory $bus_category)
    {
        return Validator::make($bus_category->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given bus_category is valid for approve status.
     *
     * @param BusCategory $bus_category
     *
     * @return bool / Validator
     */
    public function approve(BusCategory $bus_category)
    {
        return Validator::make($bus_category->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given bus_category is valid for publish status.
     *
     * @param BusCategory $bus_category
     *
     * @return bool / Validator
     */
    public function publish(BusCategory $bus_category)
    {
        return Validator::make($bus_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given bus_category is valid for archive status.
     *
     * @param BusCategory $bus_category
     *
     * @return bool / Validator
     */
    public function archive(BusCategory $bus_category)
    {
        return Validator::make($bus_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given bus_category is valid for unpublish status.
     *
     * @param BusCategory $bus_category
     *
     * @return bool / Validator
     */
    public function unpublish(BusCategory $bus_category)
    {
        return Validator::make($bus_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
